@@ -40,16 +40,41 @@ It will be used with AWS IAM Role, so you don't need to put AKSK in Gitlab envir
 
 ## Before start you need gitlab runner token in your `gitlab project` or `gitlab group`
 
-### In Group
+## In Group before Gitlab 15.10
+
+This registration process is only supported in GitLab Runner 15.10 or later
+This registration process is not supported in GitLab Runner 15.9 or earlier and only available as an experimental feature in GitLab Runner 15.10 and 15.11. You should upgrade to GitLab Runner 16.0 or later to use a stable version of this registration process. [Check this issue](https://github.com/neilkuan/cdk-gitlab-runner/issues/1796)
 
 Group > Settings > CI/CD
 ![group](image/group_runner_page.png)
 
-### In Project
+## In Group after Gitlab 15.10
+
+This registration process is only supported in GitLab Runner 15.10 or later
+This registration process is not supported in GitLab Runner 15.9 or earlier and only available as an experimental feature in GitLab Runner 15.10 and 15.11. You should upgrade to GitLab Runner 16.0 or later to use a stable version of this registration process. [Check this issue](https://github.com/neilkuan/cdk-gitlab-runner/issues/1796)
+
+Group > Build > Runners
+![group](image/gitlab-runner-new-register.png)
+![group](image/gitlab-runner-new-register-1.png)
+![group](image/gitlab-runner-new-register-2.png)
+![group](image/gitlab-runner-new-register-3.jpg)
+
+### In Project before Gitlab 15.10
+
+This registration process is only supported in GitLab Runner 15.10 or later
+This registration process is not supported in GitLab Runner 15.9 or earlier and only available as an experimental feature in GitLab Runner 15.10 and 15.11. You should upgrade to GitLab Runner 16.0 or later to use a stable version of this registration process. [Check this issue](https://github.com/neilkuan/cdk-gitlab-runner/issues/1796)
 
 Project > Settings > CI/CD > Runners
 ![project](image/project_runner_page.png)
 
+### In Project after Gitlab 15.10
+
+This registration process is only supported in GitLab Runner 15.10 or later
+This registration process is not supported in GitLab Runner 15.9 or earlier and only available as an experimental feature in GitLab Runner 15.10 and 15.11. You should upgrade to GitLab Runner 16.0 or later to use a stable version of this registration process. [Check this issue](https://github.com/neilkuan/cdk-gitlab-runner/issues/1796)
+
+Project > Settings > CI/CD > Runners
+![project](image/gitlab-runner-new-register-project.png)
+
 ## Usage
 
 Replace your gitlab runner token in `$GITLABTOKEN`
@@ -76,12 +101,12 @@ npm install cdk-gitlab-runner@cdkv1
 import { GitlabContainerRunner } from 'cdk-gitlab-runner';
 
 // If want change instance type to t3.large .
-new GitlabContainerRunner(this, 'runner-instance', { gitlabtoken: '$GITLABTOKEN', ec2type:'t3.large' });
+new GitlabContainerRunner(this, 'runner-instance', { gitlabtoken: 'glrt-GITLABTOKEN', ec2type:'t3.large',gitlabRunnerVersion: '15.10' });
 // OR
 // Just create a gitlab runner , by default instance type is t3.micro .
 import { GitlabContainerRunner } from 'cdk-gitlab-runner';
 
-new GitlabContainerRunner(this, 'runner-instance', { gitlabtoken: '$GITLABTOKEN' });})
+new GitlabContainerRunner(this, 'runner-instance', { gitlabtoken: 'glrt-GITLABTOKEN', gitlabRunnerVersion: '15.10' });
 ```
 
 ### Gitlab Server Customize Url .
@@ -93,21 +118,24 @@ If you want change what you want tag name .
 import { GitlabContainerRunner } from 'cdk-gitlab-runner';
 
 new GitlabContainerRunner(this, 'runner-instance-change-tag', {
-  gitlabtoken: '$GITLABTOKEN',
+  gitlabtoken: 'glrt-GITLABTOKEN',
   gitlaburl: 'https://gitlab.my.com/',
+  gitlabRunnerVersion: '15.10'
 });
 ```
 
 ### Tags
 
 If you want change what you want tag name .
+!!! Not support Gitlab Runner 15.10 and later !!!
 
 ```python
 // If you want change  what  you want tag name .
 import { GitlabContainerRunner } from 'cdk-gitlab-runner';
 
 new GitlabContainerRunner(this, 'runner-instance-change-tag', {
-  gitlabtoken: '$GITLABTOKEN',
+  gitlabtoken: 'glrt-GITLABTOKEN',
+  gitlabRunnerVersion: '15.10',
   tags: ['aa', 'bb', 'cc'],
 });
 ```
@@ -122,7 +150,8 @@ import { GitlabContainerRunner } from 'cdk-gitlab-runner';
 import { ManagedPolicy } from 'aws-cdk-lib/aws-iam';
 
 const runner = new GitlabContainerRunner(this, 'runner-instance-add-policy', {
-  gitlabtoken: '$GITLABTOKEN',
+  gitlabtoken: 'glrt-GITLABTOKEN',
+  gitlabRunnerVersion: '15.10',
   tags: ['aa', 'bb', 'cc'],
 });
 runner.runnerRole.addManagedPolicy(
@@ -140,7 +169,8 @@ import { GitlabContainerRunner } from 'cdk-gitlab-runner';
 import { Port, Peer } from 'aws-cdk-lib/aws-ec2';
 
 const runner = new GitlabContainerRunner(this, 'runner-add-SG-ingress', {
-  gitlabtoken: 'GITLABTOKEN',
+  gitlabtoken: 'glrt-GITLABTOKEN',
+  gitlabRunnerVersion: '15.10',
   tags: ['aa', 'bb', 'cc'],
 });
 
@@ -174,7 +204,8 @@ const newvpc = new Vpc(stack, 'VPC', {
 });
 
 const runner = new GitlabContainerRunner(this, 'testing', {
-  gitlabtoken: '$GITLABTOKEN',
+  gitlabtoken: 'glrt-GITLABTOKEN',
+  gitlabRunnerVersion: '15.10',
   ec2type: 't3.small',
   selfvpc: newvpc,
 });
@@ -196,7 +227,8 @@ const role = new Role(this, 'runner-role', {
 });
 
 const runner = new GitlabContainerRunner(stack, 'testing', {
-  gitlabtoken: '$GITLAB_TOKEN',
+  gitlabtoken: 'glrt-GITLABTOKEN',
+  gitlabRunnerVersion: '15.10',
   ec2iamrole: role,
 });
 runner.runnerRole.addManagedPolicy(
@@ -212,7 +244,8 @@ runner.runnerRole.addManagedPolicy(
 import { GitlabContainerRunner } from 'cdk-gitlab-runner';
 
 new GitlabContainerRunner(stack, 'testing', {
-  gitlabtoken: '$GITLAB_TOKEN',
+  gitlabtoken: 'glrt-GITLABTOKEN',
+  gitlabRunnerVersion: '15.10',
   ebsSize: 50,
 });
 ```
@@ -225,7 +258,8 @@ new GitlabContainerRunner(stack, 'testing', {
 import { GitlabRunnerAutoscaling } from 'cdk-gitlab-runner';
 
 new GitlabRunnerAutoscaling(stack, 'testing', {
-  gitlabToken: '$GITLAB_TOKEN',
+  gitlabToken: 'glrt-GITLABTOKEN',
+  gitlabRunnerVersion: '15.10',
   minCapacity: 2,
   maxCapacity: 2,
 });
@@ -240,7 +274,8 @@ new GitlabRunnerAutoscaling(stack, 'testing', {
 import { GitlabContainerRunner, BlockDuration } from 'cdk-gitlab-runner';
 
 const runner = new GitlabContainerRunner(stack, 'testing', {
-  gitlabtoken: 'GITLAB_TOKEN',
+  gitlabToken: 'glrt-GITLABTOKEN',
+  gitlabRunnerVersion: '15.10',
   ec2type: 't3.large',
   spotFleet: true,
 });
@@ -255,7 +290,8 @@ runner.expireAfter(Duration.hours(1));
 import { GitlabContainerRunner, BlockDuration } from 'cdk-gitlab-runner';
 
 const runner = new GitlabContainerRunner(stack, 'testing', {
-  gitlabtoken: 'GITLAB_TOKEN',
+  gitlabToken: 'glrt-GITLABTOKEN',
+  gitlabRunnerVersion: '15.10',
   ec2type: 't3.large',
   dockerVolumes: [
     {
@@ -272,6 +308,8 @@ const runner = new GitlabContainerRunner(stack, 'testing', {
 
 #### you can use tag `gitlab` , `runner` , `awscdk` ,
 
+> !!!!! Not Support Gitlab Runner after 15.10 and later
+
 ## Example *`gitlab-ci.yaml`*
 
 [gitlab docs see more ...](https://docs.gitlab.com/ee/ci/yaml/README.html)
@@ -323,6 +361,9 @@ config.toml
 
 [![Stargazers repo roster for @neilkuan/cdk-gitlab-runner](https://reporoster.com/stars/neilkuan/cdk-gitlab-runner)](https://github.com/neilkuan/cdk-gitlab-runner/stargazers)
 '''
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -430,12 +471,14 @@ class GitlabContainerRunner(
         scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
+        gitlab_runner_version: builtins.str,
         gitlabtoken: builtins.str,
         concurrent_jobs: typing.Optional[jsii.Number] = None,
         docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[builtins.str, typing.Any]]]] = None,
         ebs_size: typing.Optional[jsii.Number] = None,
         ec2iamrole: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
         ec2type: typing.Optional[builtins.str] = None,
+        enabled_imd_sv2: typing.Optional[builtins.bool] = None,
         gitlab_runner_image: typing.Optional[builtins.str] = None,
         gitlaburl: typing.Optional[builtins.str] = None,
         instance_interruption_behavior: typing.Optional["InstanceInterruptionBehavior"] = None,
@@ -443,9 +486,6 @@ class GitlabContainerRunner(
         runner_description: typing.Optional[builtins.str] = None,
         selfvpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
         spot_fleet: typing.Optional[builtins.bool] = None,
-        tag1: typing.Optional[builtins.str] = None,
-        tag2: typing.Optional[builtins.str] = None,
-        tag3: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
         valid_until: typing.Optional[builtins.str] = None,
         vpc_subnet: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
@@ -453,23 +493,22 @@ class GitlabContainerRunner(
         '''
         :param scope: -
         :param id: -
+        :param gitlab_runner_version: (experimental) Gitlab Runner version Please give me gitlab runner version.
         :param gitlabtoken: (experimental) Gitlab token for the Register Runner . Default: - You must to give the token !!!
         :param concurrent_jobs: (experimental) Gitlab Runner concurrent job configuration. Default: - concurrentJobs=1
         :param docker_volumes: (experimental) add another Gitlab Container Runner Docker Volumes Path at job runner runtime. more detail see https://docs.gitlab.com/runner/configuration/advanced-configuration.html#the-runnersdocker-section Default: - already mount "/var/run/docker.sock:/var/run/docker.sock"
         :param ebs_size: (experimental) Gitlab Runner instance EBS size . Default: - ebsSize=60
         :param ec2iamrole: (experimental) IAM role for the Gitlab Runner Instance . Default: - new Role for Gitlab Runner Instance , attach AmazonSSMManagedInstanceCore Policy .
         :param ec2type: (experimental) Runner default EC2 instance type. Default: - t3.micro
-        :param gitlab_runner_image: (experimental) Image URL of Gitlab Runner. Default: public.ecr.aws/gitlab/gitlab-runner:latest
+        :param enabled_imd_sv2: (experimental) Enabled IMDSv2. more detail see https://docs.aws.amazon.com/zh_tw/AWSEC2/latest/UserGuide/configuring-instance-metadata-service.html Default: - false
+        :param gitlab_runner_image: (experimental) Image URL of Gitlab Runner. Default: public.ecr.aws/gitlab/gitlab-runner:latest !!! <--- latest now > 16.0 Gitlab Runner version
         :param gitlaburl: (experimental) Gitlab Runner register url . Default: - gitlaburl='https://gitlab.com/' , please use https://yourgitlab.com/ do not use https://yourgitlab.com
         :param instance_interruption_behavior: (experimental) The behavior when a Spot Runner Instance is interrupted. Default: - InstanceInterruptionBehavior.TERMINATE , !!! only support spotfleet runner !!! .
         :param key_name: (experimental) SSH key name. Default: - no ssh key will be assigned , !!! only support spotfleet runner !!! .
         :param runner_description: (experimental) Gitlab Runner description. Default: - runnerDescription='Docker Runner'
         :param selfvpc: (experimental) VPC for the Gitlab Runner . Default: - new VPC will be created , 1 Vpc , 2 Public Subnet .
         :param spot_fleet: (experimental) Gitlab Runner instance Use Spot Fleet or not ?!. Default: - spotFleet=false
-        :param tag1: (deprecated) Gitlab Runner register tag1 . Default: - tag1: gitlab .
-        :param tag2: (deprecated) Gitlab Runner register tag2 . Default: - tag2: awscdk .
-        :param tag3: (deprecated) Gitlab Runner register tag3 . Default: - tag3: runner .
-        :param tags: (experimental) tags for the runner. Default: - ['runner', 'gitlab', 'awscdk']
+        :param tags: (experimental) tags for the runner Unsupported Gitlab Runner 15.10 and later. Default: - ['runner', 'gitlab', 'awscdk']
         :param valid_until: (experimental) the time when the spot fleet allocation expires. Default: - no expiration , !!! only support spotfleet runner !!! .
         :param vpc_subnet: (experimental) VPC subnet for the spot fleet. Default: - public subnet
 
@@ -480,12 +519,14 @@ class GitlabContainerRunner(
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GitlabContainerRunnerProps(
+            gitlab_runner_version=gitlab_runner_version,
             gitlabtoken=gitlabtoken,
             concurrent_jobs=concurrent_jobs,
             docker_volumes=docker_volumes,
             ebs_size=ebs_size,
             ec2iamrole=ec2iamrole,
             ec2type=ec2type,
+            enabled_imd_sv2=enabled_imd_sv2,
             gitlab_runner_image=gitlab_runner_image,
             gitlaburl=gitlaburl,
             instance_interruption_behavior=instance_interruption_behavior,
@@ -493,9 +534,6 @@ class GitlabContainerRunner(
             runner_description=runner_description,
             selfvpc=selfvpc,
             spot_fleet=spot_fleet,
-            tag1=tag1,
-            tag2=tag2,
-            tag3=tag3,
             tags=tags,
             valid_until=valid_until,
             vpc_subnet=vpc_subnet,
@@ -595,12 +633,14 @@ class GitlabContainerRunner(
     jsii_type="cdk-gitlab-runner.GitlabContainerRunnerProps",
     jsii_struct_bases=[],
     name_mapping={
+        "gitlab_runner_version": "gitlabRunnerVersion",
         "gitlabtoken": "gitlabtoken",
         "concurrent_jobs": "concurrentJobs",
         "docker_volumes": "dockerVolumes",
         "ebs_size": "ebsSize",
         "ec2iamrole": "ec2iamrole",
         "ec2type": "ec2type",
+        "enabled_imd_sv2": "enabledIMDSv2",
         "gitlab_runner_image": "gitlabRunnerImage",
         "gitlaburl": "gitlaburl",
         "instance_interruption_behavior": "instanceInterruptionBehavior",
@@ -608,9 +648,6 @@ class GitlabContainerRunner(
         "runner_description": "runnerDescription",
         "selfvpc": "selfvpc",
         "spot_fleet": "spotFleet",
-        "tag1": "tag1",
-        "tag2": "tag2",
-        "tag3": "tag3",
         "tags": "tags",
         "valid_until": "validUntil",
         "vpc_subnet": "vpcSubnet",
@@ -620,12 +657,14 @@ class GitlabContainerRunnerProps:
     def __init__(
         self,
         *,
+        gitlab_runner_version: builtins.str,
         gitlabtoken: builtins.str,
         concurrent_jobs: typing.Optional[jsii.Number] = None,
         docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[builtins.str, typing.Any]]]] = None,
         ebs_size: typing.Optional[jsii.Number] = None,
         ec2iamrole: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
         ec2type: typing.Optional[builtins.str] = None,
+        enabled_imd_sv2: typing.Optional[builtins.bool] = None,
         gitlab_runner_image: typing.Optional[builtins.str] = None,
         gitlaburl: typing.Optional[builtins.str] = None,
         instance_interruption_behavior: typing.Optional["InstanceInterruptionBehavior"] = None,
@@ -633,32 +672,28 @@ class GitlabContainerRunnerProps:
         runner_description: typing.Optional[builtins.str] = None,
         selfvpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
         spot_fleet: typing.Optional[builtins.bool] = None,
-        tag1: typing.Optional[builtins.str] = None,
-        tag2: typing.Optional[builtins.str] = None,
-        tag3: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
         valid_until: typing.Optional[builtins.str] = None,
         vpc_subnet: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''(experimental) GitlabContainerRunner Props.
 
+        :param gitlab_runner_version: (experimental) Gitlab Runner version Please give me gitlab runner version.
         :param gitlabtoken: (experimental) Gitlab token for the Register Runner . Default: - You must to give the token !!!
         :param concurrent_jobs: (experimental) Gitlab Runner concurrent job configuration. Default: - concurrentJobs=1
         :param docker_volumes: (experimental) add another Gitlab Container Runner Docker Volumes Path at job runner runtime. more detail see https://docs.gitlab.com/runner/configuration/advanced-configuration.html#the-runnersdocker-section Default: - already mount "/var/run/docker.sock:/var/run/docker.sock"
         :param ebs_size: (experimental) Gitlab Runner instance EBS size . Default: - ebsSize=60
         :param ec2iamrole: (experimental) IAM role for the Gitlab Runner Instance . Default: - new Role for Gitlab Runner Instance , attach AmazonSSMManagedInstanceCore Policy .
         :param ec2type: (experimental) Runner default EC2 instance type. Default: - t3.micro
-        :param gitlab_runner_image: (experimental) Image URL of Gitlab Runner. Default: public.ecr.aws/gitlab/gitlab-runner:latest
+        :param enabled_imd_sv2: (experimental) Enabled IMDSv2. more detail see https://docs.aws.amazon.com/zh_tw/AWSEC2/latest/UserGuide/configuring-instance-metadata-service.html Default: - false
+        :param gitlab_runner_image: (experimental) Image URL of Gitlab Runner. Default: public.ecr.aws/gitlab/gitlab-runner:latest !!! <--- latest now > 16.0 Gitlab Runner version
         :param gitlaburl: (experimental) Gitlab Runner register url . Default: - gitlaburl='https://gitlab.com/' , please use https://yourgitlab.com/ do not use https://yourgitlab.com
         :param instance_interruption_behavior: (experimental) The behavior when a Spot Runner Instance is interrupted. Default: - InstanceInterruptionBehavior.TERMINATE , !!! only support spotfleet runner !!! .
         :param key_name: (experimental) SSH key name. Default: - no ssh key will be assigned , !!! only support spotfleet runner !!! .
         :param runner_description: (experimental) Gitlab Runner description. Default: - runnerDescription='Docker Runner'
         :param selfvpc: (experimental) VPC for the Gitlab Runner . Default: - new VPC will be created , 1 Vpc , 2 Public Subnet .
         :param spot_fleet: (experimental) Gitlab Runner instance Use Spot Fleet or not ?!. Default: - spotFleet=false
-        :param tag1: (deprecated) Gitlab Runner register tag1 . Default: - tag1: gitlab .
-        :param tag2: (deprecated) Gitlab Runner register tag2 . Default: - tag2: awscdk .
-        :param tag3: (deprecated) Gitlab Runner register tag3 . Default: - tag3: runner .
-        :param tags: (experimental) tags for the runner. Default: - ['runner', 'gitlab', 'awscdk']
+        :param tags: (experimental) tags for the runner Unsupported Gitlab Runner 15.10 and later. Default: - ['runner', 'gitlab', 'awscdk']
         :param valid_until: (experimental) the time when the spot fleet allocation expires. Default: - no expiration , !!! only support spotfleet runner !!! .
         :param vpc_subnet: (experimental) VPC subnet for the spot fleet. Default: - public subnet
 
@@ -668,12 +703,14 @@ class GitlabContainerRunnerProps:
             vpc_subnet = _aws_cdk_aws_ec2_ceddda9d.SubnetSelection(**vpc_subnet)
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__0026c0e7fdafbb0c3cfac95f254acf8fbd8eb0fb39b8b1e9cd3089655e745dbe)
+            check_type(argname="argument gitlab_runner_version", value=gitlab_runner_version, expected_type=type_hints["gitlab_runner_version"])
             check_type(argname="argument gitlabtoken", value=gitlabtoken, expected_type=type_hints["gitlabtoken"])
             check_type(argname="argument concurrent_jobs", value=concurrent_jobs, expected_type=type_hints["concurrent_jobs"])
             check_type(argname="argument docker_volumes", value=docker_volumes, expected_type=type_hints["docker_volumes"])
             check_type(argname="argument ebs_size", value=ebs_size, expected_type=type_hints["ebs_size"])
             check_type(argname="argument ec2iamrole", value=ec2iamrole, expected_type=type_hints["ec2iamrole"])
             check_type(argname="argument ec2type", value=ec2type, expected_type=type_hints["ec2type"])
+            check_type(argname="argument enabled_imd_sv2", value=enabled_imd_sv2, expected_type=type_hints["enabled_imd_sv2"])
             check_type(argname="argument gitlab_runner_image", value=gitlab_runner_image, expected_type=type_hints["gitlab_runner_image"])
             check_type(argname="argument gitlaburl", value=gitlaburl, expected_type=type_hints["gitlaburl"])
             check_type(argname="argument instance_interruption_behavior", value=instance_interruption_behavior, expected_type=type_hints["instance_interruption_behavior"])
@@ -681,13 +718,11 @@ class GitlabContainerRunnerProps:
             check_type(argname="argument runner_description", value=runner_description, expected_type=type_hints["runner_description"])
             check_type(argname="argument selfvpc", value=selfvpc, expected_type=type_hints["selfvpc"])
             check_type(argname="argument spot_fleet", value=spot_fleet, expected_type=type_hints["spot_fleet"])
-            check_type(argname="argument tag1", value=tag1, expected_type=type_hints["tag1"])
-            check_type(argname="argument tag2", value=tag2, expected_type=type_hints["tag2"])
-            check_type(argname="argument tag3", value=tag3, expected_type=type_hints["tag3"])
             check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
             check_type(argname="argument valid_until", value=valid_until, expected_type=type_hints["valid_until"])
             check_type(argname="argument vpc_subnet", value=vpc_subnet, expected_type=type_hints["vpc_subnet"])
         self._values: typing.Dict[builtins.str, typing.Any] = {
+            "gitlab_runner_version": gitlab_runner_version,
             "gitlabtoken": gitlabtoken,
         }
         if concurrent_jobs is not None:
@@ -700,6 +735,8 @@ class GitlabContainerRunnerProps:
             self._values["ec2iamrole"] = ec2iamrole
         if ec2type is not None:
             self._values["ec2type"] = ec2type
+        if enabled_imd_sv2 is not None:
+            self._values["enabled_imd_sv2"] = enabled_imd_sv2
         if gitlab_runner_image is not None:
             self._values["gitlab_runner_image"] = gitlab_runner_image
         if gitlaburl is not None:
@@ -714,12 +751,6 @@ class GitlabContainerRunnerProps:
             self._values["selfvpc"] = selfvpc
         if spot_fleet is not None:
             self._values["spot_fleet"] = spot_fleet
-        if tag1 is not None:
-            self._values["tag1"] = tag1
-        if tag2 is not None:
-            self._values["tag2"] = tag2
-        if tag3 is not None:
-            self._values["tag3"] = tag3
         if tags is not None:
             self._values["tags"] = tags
         if valid_until is not None:
@@ -727,6 +758,16 @@ class GitlabContainerRunnerProps:
         if vpc_subnet is not None:
             self._values["vpc_subnet"] = vpc_subnet
 
+    @builtins.property
+    def gitlab_runner_version(self) -> builtins.str:
+        '''(experimental) Gitlab Runner version Please give me gitlab runner version.
+
+        :stability: experimental
+        '''
+        result = self._values.get("gitlab_runner_version")
+        assert result is not None, "Required property 'gitlab_runner_version' is missing"
+        return typing.cast(builtins.str, result)
+
     @builtins.property
     def gitlabtoken(self) -> builtins.str:
         '''(experimental) Gitlab token for the Register Runner .
@@ -831,11 +872,24 @@ class GitlabContainerRunnerProps:
         result = self._values.get("ec2type")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def enabled_imd_sv2(self) -> typing.Optional[builtins.bool]:
+        '''(experimental) Enabled IMDSv2.
+
+        more detail see https://docs.aws.amazon.com/zh_tw/AWSEC2/latest/UserGuide/configuring-instance-metadata-service.html
+
+        :default: - false
+
+        :stability: experimental
+        '''
+        result = self._values.get("enabled_imd_sv2")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def gitlab_runner_image(self) -> typing.Optional[builtins.str]:
         '''(experimental) Image URL of Gitlab Runner.
 
-        :default: public.ecr.aws/gitlab/gitlab-runner:latest
+        :default: public.ecr.aws/gitlab/gitlab-runner:latest !!! <--- latest now > 16.0 Gitlab Runner version
 
         :stability: experimental
 
@@ -941,63 +995,13 @@ class GitlabContainerRunnerProps:
         result = self._values.get("spot_fleet")
         return typing.cast(typing.Optional[builtins.bool], result)
 
-    @builtins.property
-    def tag1(self) -> typing.Optional[builtins.str]:
-        '''(deprecated) Gitlab Runner register tag1  .
-
-        :default: - tag1: gitlab .
-
-        :deprecated: - use tags ['runner', 'gitlab', 'awscdk']
-
-        :stability: deprecated
-
-        Example::
-
-            new GitlabContainerRunner(stack, 'runner', { gitlabtoken: 'GITLAB_TOKEN', tag1: 'aa' });
-        '''
-        result = self._values.get("tag1")
-        return typing.cast(typing.Optional[builtins.str], result)
-
-    @builtins.property
-    def tag2(self) -> typing.Optional[builtins.str]:
-        '''(deprecated) Gitlab Runner register tag2  .
-
-        :default: - tag2: awscdk .
-
-        :deprecated: - use tags ['runner', 'gitlab', 'awscdk']
-
-        :stability: deprecated
-
-        Example::
-
-            new GitlabContainerRunner(stack, 'runner', { gitlabtoken: 'GITLAB_TOKEN', tag2: 'bb' });
-        '''
-        result = self._values.get("tag2")
-        return typing.cast(typing.Optional[builtins.str], result)
-
-    @builtins.property
-    def tag3(self) -> typing.Optional[builtins.str]:
-        '''(deprecated) Gitlab Runner register tag3  .
-
-        :default: - tag3: runner .
-
-        :deprecated: - use tags ['runner', 'gitlab', 'awscdk']
-
-        :stability: deprecated
-
-        Example::
-
-            new GitlabContainerRunner(stack, 'runner', { gitlabtoken: 'GITLAB_TOKEN', tag3: 'cc' });
-        '''
-        result = self._values.get("tag3")
-        return typing.cast(typing.Optional[builtins.str], result)
-
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[builtins.str]]:
-        '''(experimental) tags for the runner.
+        '''(experimental) tags for the runner Unsupported Gitlab Runner 15.10 and later.
 
         :default: - ['runner', 'gitlab', 'awscdk']
 
+        :see: - https://docs.gitlab.com/ee/ci/runners/new_creation_workflow.html
         :stability: experimental
         '''
         result = self._values.get("tags")
@@ -1069,6 +1073,7 @@ class GitlabRunnerAutoscaling(
         scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
+        gitlab_runner_version: builtins.str,
         gitlab_token: builtins.str,
         alarms: typing.Optional[typing.Sequence[typing.Mapping[typing.Any, typing.Any]]] = None,
         desired_capacity: typing.Optional[jsii.Number] = None,
@@ -1088,6 +1093,7 @@ class GitlabRunnerAutoscaling(
         '''
         :param scope: -
         :param id: -
+        :param gitlab_runner_version: (experimental) Gitlab Runner version Please give me gitlab runner version.
         :param gitlab_token: (experimental) Gitlab token.
         :param alarms: (experimental) Parameters of put_metric_alarm function. https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_alarm Default: - [{ AlarmName: 'GitlabRunnerDiskUsage', MetricName: 'disk_used_percent', }]
         :param desired_capacity: (experimental) Desired capacity limit for autoscaling group. Default: - minCapacity, and leave unchanged during deployment
@@ -1111,6 +1117,7 @@ class GitlabRunnerAutoscaling(
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GitlabRunnerAutoscalingProps(
+            gitlab_runner_version=gitlab_runner_version,
             gitlab_token=gitlab_token,
             alarms=alarms,
             desired_capacity=desired_capacity,
@@ -1134,6 +1141,7 @@ class GitlabRunnerAutoscaling(
     def create_user_data(
         self,
         *,
+        gitlab_runner_version: builtins.str,
         gitlab_token: builtins.str,
         alarms: typing.Optional[typing.Sequence[typing.Mapping[typing.Any, typing.Any]]] = None,
         desired_capacity: typing.Optional[jsii.Number] = None,
@@ -1151,6 +1159,7 @@ class GitlabRunnerAutoscaling(
         vpc_subnet: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> typing.List[builtins.str]:
         '''
+        :param gitlab_runner_version: (experimental) Gitlab Runner version Please give me gitlab runner version.
         :param gitlab_token: (experimental) Gitlab token.
         :param alarms: (experimental) Parameters of put_metric_alarm function. https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_alarm Default: - [{ AlarmName: 'GitlabRunnerDiskUsage', MetricName: 'disk_used_percent', }]
         :param desired_capacity: (experimental) Desired capacity limit for autoscaling group. Default: - minCapacity, and leave unchanged during deployment
@@ -1172,6 +1181,7 @@ class GitlabRunnerAutoscaling(
         :stability: experimental
         '''
         props = GitlabRunnerAutoscalingProps(
+            gitlab_runner_version=gitlab_runner_version,
             gitlab_token=gitlab_token,
             alarms=alarms,
             desired_capacity=desired_capacity,
@@ -1241,6 +1251,7 @@ class GitlabRunnerAutoscaling(
     jsii_type="cdk-gitlab-runner.GitlabRunnerAutoscalingProps",
     jsii_struct_bases=[],
     name_mapping={
+        "gitlab_runner_version": "gitlabRunnerVersion",
         "gitlab_token": "gitlabToken",
         "alarms": "alarms",
         "desired_capacity": "desiredCapacity",
@@ -1262,6 +1273,7 @@ class GitlabRunnerAutoscalingProps:
     def __init__(
         self,
         *,
+        gitlab_runner_version: builtins.str,
         gitlab_token: builtins.str,
         alarms: typing.Optional[typing.Sequence[typing.Mapping[typing.Any, typing.Any]]] = None,
         desired_capacity: typing.Optional[jsii.Number] = None,
@@ -1280,6 +1292,7 @@ class GitlabRunnerAutoscalingProps:
     ) -> None:
         '''(experimental) GitlabRunnerAutoscaling Props.
 
+        :param gitlab_runner_version: (experimental) Gitlab Runner version Please give me gitlab runner version.
         :param gitlab_token: (experimental) Gitlab token.
         :param alarms: (experimental) Parameters of put_metric_alarm function. https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_alarm Default: - [{ AlarmName: 'GitlabRunnerDiskUsage', MetricName: 'disk_used_percent', }]
         :param desired_capacity: (experimental) Desired capacity limit for autoscaling group. Default: - minCapacity, and leave unchanged during deployment
@@ -1302,6 +1315,7 @@ class GitlabRunnerAutoscalingProps:
             vpc_subnet = _aws_cdk_aws_ec2_ceddda9d.SubnetSelection(**vpc_subnet)
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__456bc54665e983cecf5d286556d3b391003886fdd1d6f537def2467508670cc9)
+            check_type(argname="argument gitlab_runner_version", value=gitlab_runner_version, expected_type=type_hints["gitlab_runner_version"])
             check_type(argname="argument gitlab_token", value=gitlab_token, expected_type=type_hints["gitlab_token"])
             check_type(argname="argument alarms", value=alarms, expected_type=type_hints["alarms"])
             check_type(argname="argument desired_capacity", value=desired_capacity, expected_type=type_hints["desired_capacity"])
@@ -1318,6 +1332,7 @@ class GitlabRunnerAutoscalingProps:
             check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
             check_type(argname="argument vpc_subnet", value=vpc_subnet, expected_type=type_hints["vpc_subnet"])
         self._values: typing.Dict[builtins.str, typing.Any] = {
+            "gitlab_runner_version": gitlab_runner_version,
             "gitlab_token": gitlab_token,
         }
         if alarms is not None:
@@ -1349,6 +1364,16 @@ class GitlabRunnerAutoscalingProps:
         if vpc_subnet is not None:
             self._values["vpc_subnet"] = vpc_subnet
 
+    @builtins.property
+    def gitlab_runner_version(self) -> builtins.str:
+        '''(experimental) Gitlab Runner version Please give me gitlab runner version.
+
+        :stability: experimental
+        '''
+        result = self._values.get("gitlab_runner_version")
+        assert result is not None, "Required property 'gitlab_runner_version' is missing"
+        return typing.cast(builtins.str, result)
+
     @builtins.property
     def gitlab_token(self) -> builtins.str:
         '''(experimental) Gitlab token.
@@ -1666,12 +1691,14 @@ def _typecheckingstub__3569128cd1ccb4f615528e61f1622fdbd79cb2ae3e5d8a3297d682bf4
     scope: _constructs_77d1e7e8.Construct,
     id: builtins.str,
     *,
+    gitlab_runner_version: builtins.str,
     gitlabtoken: builtins.str,
     concurrent_jobs: typing.Optional[jsii.Number] = None,
     docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[builtins.str, typing.Any]]]] = None,
     ebs_size: typing.Optional[jsii.Number] = None,
     ec2iamrole: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
     ec2type: typing.Optional[builtins.str] = None,
+    enabled_imd_sv2: typing.Optional[builtins.bool] = None,
     gitlab_runner_image: typing.Optional[builtins.str] = None,
     gitlaburl: typing.Optional[builtins.str] = None,
     instance_interruption_behavior: typing.Optional[InstanceInterruptionBehavior] = None,
@@ -1679,9 +1706,6 @@ def _typecheckingstub__3569128cd1ccb4f615528e61f1622fdbd79cb2ae3e5d8a3297d682bf4
     runner_description: typing.Optional[builtins.str] = None,
     selfvpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
     spot_fleet: typing.Optional[builtins.bool] = None,
-    tag1: typing.Optional[builtins.str] = None,
-    tag2: typing.Optional[builtins.str] = None,
-    tag3: typing.Optional[builtins.str] = None,
     tags: typing.Optional[typing.Sequence[builtins.str]] = None,
     valid_until: typing.Optional[builtins.str] = None,
     vpc_subnet: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
@@ -1704,12 +1728,14 @@ def _typecheckingstub__573d5bebeef3dab5acf1ce20fe1bec4b423b45aa004fd1962be44c7be
 
 def _typecheckingstub__0026c0e7fdafbb0c3cfac95f254acf8fbd8eb0fb39b8b1e9cd3089655e745dbe(
     *,
+    gitlab_runner_version: builtins.str,
     gitlabtoken: builtins.str,
     concurrent_jobs: typing.Optional[jsii.Number] = None,
     docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[builtins.str, typing.Any]]]] = None,
     ebs_size: typing.Optional[jsii.Number] = None,
     ec2iamrole: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
     ec2type: typing.Optional[builtins.str] = None,
+    enabled_imd_sv2: typing.Optional[builtins.bool] = None,
     gitlab_runner_image: typing.Optional[builtins.str] = None,
     gitlaburl: typing.Optional[builtins.str] = None,
     instance_interruption_behavior: typing.Optional[InstanceInterruptionBehavior] = None,
@@ -1717,9 +1743,6 @@ def _typecheckingstub__0026c0e7fdafbb0c3cfac95f254acf8fbd8eb0fb39b8b1e9cd3089655
     runner_description: typing.Optional[builtins.str] = None,
     selfvpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
     spot_fleet: typing.Optional[builtins.bool] = None,
-    tag1: typing.Optional[builtins.str] = None,
-    tag2: typing.Optional[builtins.str] = None,
-    tag3: typing.Optional[builtins.str] = None,
     tags: typing.Optional[typing.Sequence[builtins.str]] = None,
     valid_until: typing.Optional[builtins.str] = None,
     vpc_subnet: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
@@ -1731,6 +1754,7 @@ def _typecheckingstub__e1346a7c57bd8e3d5b6fd96e74f7310063137cbf2338091d3cb96f36a
     scope: _constructs_77d1e7e8.Construct,
     id: builtins.str,
     *,
+    gitlab_runner_version: builtins.str,
     gitlab_token: builtins.str,
     alarms: typing.Optional[typing.Sequence[typing.Mapping[typing.Any, typing.Any]]] = None,
     desired_capacity: typing.Optional[jsii.Number] = None,
@@ -1752,6 +1776,7 @@ def _typecheckingstub__e1346a7c57bd8e3d5b6fd96e74f7310063137cbf2338091d3cb96f36a
 
 def _typecheckingstub__456bc54665e983cecf5d286556d3b391003886fdd1d6f537def2467508670cc9(
     *,
+    gitlab_runner_version: builtins.str,
     gitlab_token: builtins.str,
     alarms: typing.Optional[typing.Sequence[typing.Mapping[typing.Any, typing.Any]]] = None,
     desired_capacity: typing.Optional[jsii.Number] = None,
