@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -15,9 +18,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-gitlab-runner",
-    "2.1.332",
+    "2.2.118",
     __name__[0:-6],
-    "cdk-gitlab-runner@2.1.332.jsii.tgz",
+    "cdk-gitlab-runner@2.2.118.jsii.tgz",
 )
 
 __all__ = [
